@@ -9,23 +9,23 @@
 #' @param B Number of bootstrap samples, default is 100
 #' @param iter.max Maximum number of iteration used in iSIS, default=10 (details see the SIS package)
 #' @param nsis Number of pedictors recruited by iSIS
-#' @param filtering T: filtering mediators based on the strength of indp and mediators as a preprocessing step; F: all putative mediators are included, default=F.
+#' @param filtering TRUE: filtering mediators based on the strength of indp and mediators as a preprocessing step; FALSE: all putative mediators are included, default=FALSE.
 #' @param init.FDR.cutoff FDR threshold for the filtering method on M1 type of mediators.
 #' @return CI: The 95 percent confidence intervals of Rsq measure (Rsq.mediated), shared over simple effects (SOS), number of mediators selected (pab), variance of outcome explained by mediator (Rsq.YM), variance of outcome explained by the independent variable (Rsq.YX), and variance of outcome explained by mediator and independent variable (Rsq.YMX). The estimates for each bootstrap are also returned.
 #' @export
 #' @examples {
-#'  \dontrun{
+#'  \donttest{
 #' data(example)
 #' attach(example)
 #' CI.Rsq.measure( p=1/2, Y=Y,M=M,X=X,method='ALL', B=1, iter.max=1)
 #' }
 #'}
-CI.Rsq.measure <- function( p=1/2, Y,M,Covar=NULL,X, method=c('iSIS','ALL'),B=200, iter.max=3, nsis=NULL, init.FDR.cutoff=0.1, filtering=F){
+CI.Rsq.measure <- function( p=1/2, Y,M,Covar=NULL,X, method=c('iSIS','ALL'),B=200, iter.max=3, nsis=NULL, init.FDR.cutoff=0.1, filtering=FALSE){
 if (is.null(nsis)) nsis=length(Y)/log(length(Y))
 output <- matrix(NA, nrow=B, ncol=10)
 for (kk in 1:B){
 set.seed(kk)
-ID <- sample(1:length(Y),length(Y), replace=T)
+ID <- sample(1:length(Y),length(Y), replace=TRUE)
 #ID <- 1:length(Y)
 outcome_cl <- Y[ID]
 med_cl <- M[ID,]
